@@ -231,10 +231,10 @@ class BidirectionalStreamingMethod:
 
 
 def create_dart_file(package: str):
-    content = '''import 'auth.dart';
+    content = f'''import 'auth.dart';
 import 'client.dart';
 import 'package:grpc/grpc.dart';
-import 'models.pbgrpc.dart';
+import '{package}.pbgrpc.dart';
 
 '''
     messages: list[MessageInfo] = []
