@@ -10,9 +10,11 @@ from protmo.pm import Message
 
 DB_KEY = 1
 
+
 def db() -> Db:
     return use_provided(DB_KEY)
 
+
 class Db:
     '''
     Db is an abstration on top of MongoDb and provides a fitting interface to
@@ -85,7 +87,10 @@ class Db:
         return res[0]
 
     def all(self, messageClass: type, include_deleted=False):
-        return self.query(messageClass, query={}, include_deleted=include_deleted)
+        return self.query(
+            messageClass,
+            query={},
+            include_deleted=include_deleted)
 
     def query(self, messageClass: type, query: Dict = {},
               include_deleted: bool = False) -> List[Message]:
