@@ -10,6 +10,7 @@ from typing import Any
 from protmo.name_to_protobuf import *
 from protmo.provide import use_provided
 
+
 def request_user():
     USER_KEY = 2
     return use_provided(USER_KEY)
@@ -108,15 +109,15 @@ class Message:
         # via kwargs. In this way to user can use the Message class as if it would be a
         # proto-message and we can extend our functionality around it.
         name = cls.__name__
-        try:
-            proto = name_to_grpc_message_or_method(name)()
-            proto = ParseDict(kwargs, proto, ignore_unknown_fields=True)
-        except Exception as e:
-            # TODO: this is called in regen, but there is no proto-file as it is just generated
-            # right now. Thus name_to_grpc_message_or_method(name) returns None, which causes an error
-            # but this should be the normal case at this state, thus there is
-            # an design error here
+
+        proto = name_to_grpc_message_or_method(name)
+        if not proto:
+            # print(f'message "{name}" not found')
             proto = None
+        else:
+            proto = proto()
+            proto = ParseDict(kwargs, proto, ignore_unknown_fields=True)
+
         # We use the Message class to wrap the proto-message-class which holds the actual data.
         # thus we set the data into the proto-attribute and whenever someone asks us for data
         # we take it from there
@@ -192,8 +193,8 @@ class Message:
         # More complexity is added because we alsow allow repeated ReferenceFields
         # to allow unidirectoral Many-To-Many definition
         attribute_value = attr(name)
-        if isinstance(attribute_value, ReferenceField):  # lazy load first!
 
+        if isinstance(attribute_value, ReferenceField):  # lazy load first!
             if attribute_value.repeated:
                 foreign_objects_ids = list(
                     getattr(attr('proto'), attribute_value.name))
@@ -207,6 +208,7 @@ class Message:
                 return db_res
 
             else:  # not repeatet
+
                 foreign_object_id = getattr(
                     attr('proto'), attribute_value.name)
                 if foreign_object_id:
