@@ -8,6 +8,9 @@ from protmo.pm import name_to_grpc_message_or_method
 from protmo.utils import *
 from protmo.server.generic_servicer import GenericServicer
 
+
+
+
 def run_server(): # -> NoReturn:
     '''
     You first have to load all modules (as defined in your settings.py) and then
@@ -30,8 +33,11 @@ def load_modules() -> None:
             __import__(module + '.' + 'models')
     try: # check, if there is a models.py in root (a shortcut)
         __import__('models')
-    except:
+    except Exception as e:
+        print('Error in models.py')
+        print(e)
         pass # 
+ 
 
 def serve(): # -> NoReturn:
     '''
@@ -72,8 +78,9 @@ def _register_models_to_server(server: _Server) -> None:
         _messages_by_name[ModelClass.__name__] = ModelClass
         try:
             _register_model_at_grpc_server(ModelClass, server)
+            # print(ModelClass, 'registered')
         except AttributeError as e:
-            pass # ok, not all Models have Servicers
+            pass # ok, not all Models have Servicers, only those with @rpc-methods
 
 
 def _register_model_at_grpc_server(ModelClass: type, server: _Server) -> None:
